package main

import (
	"context"
	"lmika.dev/lmika/hugo-crm/config"
	"lmika.dev/lmika/hugo-crm/providers/db"
	"lmika.dev/lmika/hugo-crm/providers/git"
	"lmika.dev/lmika/hugo-crm/providers/hugo"
	"lmika.dev/lmika/hugo-crm/providers/themes"
	"lmika.dev/lmika/hugo-crm/services/sites"
	"log"
	"time"
)

func main() {
	cfg, err := config.Load()
	if err != nil {
		log.Fatal(err)
	}

	dbp, err := db.New(cfg.DatabaseURL)
	if err != nil {
		log.Fatal(err)
	}
	defer dbp.Close()

	hugoProvider, err := hugo.New(cfg.StagingDir())
	if err != nil {
		log.Fatal(err)
	}
	gitProvider := git.New()
	themesProvider := themes.New()

	siteService := sites.NewService(cfg, dbp, themesProvider, gitProvider, hugoProvider)

	log.Println("Connected to database")
	if err := dbp.Migrate(context.Background()); err != nil {
		log.Fatal(err)
	}

	log.Println("Database migrated")

	if _, err := siteService.CreateSite(context.Background(), "Test site "+time.Now().Format("2006-01-02T15:04:05")); err != nil {
		log.Fatal(err)
	}
}
